@@ -101,8 +101,8 @@ pairwise_fisher_test <- function(dep_var, indep_var, adjmethod = "fdr", plevel =
 #' @param symbols predefined as b,c, d...;  provides footnotes to mark group
 #' differences, e.g. b means different from group 2
 #' @param ref is the 1st subgroup the reference (like in Dunnett test)
-#' @param cmh Should  Cochran-Mantel-Haenszel test (\link{cmh_test}) be used for
-#' testing? If false, the linear-by-linear association test (\link{lbl_test})
+#' @param cmh Should  Cochran-Mantel-Haenszel test ([coin::cmh_test]) be used for
+#' testing? If false, the linear-by-linear association test ([coin::lbl_test])
 #' is applied.
 #'
 #' @return
@@ -184,6 +184,7 @@ pairwise_ordcat_test <- function(dep_var, indep_var, adjmethod = "fdr", plevel =
 #' If less than 2 values are provided, NA is returned.
 #'
 #' @param x Vector of data to test.
+#' @param lillie Logical, should the Lilliefors test be used? Defaults to TRUE
 #'
 #' @return p.value from \link{ks.test}.
 #'
@@ -194,14 +195,24 @@ pairwise_ordcat_test <- function(dep_var, indep_var, adjmethod = "fdr", plevel =
 #'   sd = sd(mtcars$wt, na.rm = TRUE)
 #' )
 #' # wrapped version:
-#' ksnormal(x = mtcars$wt)
+#' ksnormal(x = mtcars$wt, lillie=FALSE)
 #' @export
-ksnormal <- function(x) {
+ksnormal <- function(x, lillie=TRUE) {
   if(length(na.omit(x))>1){
-  suppressWarnings(
-    assign("ksout",ks.test(x, "pnorm", mean(x, na.rm = TRUE), sd(x, na.rm = TRUE),
-                     exact = FALSE
-    )$p.value))
+    if(lillie){
+    assign("ksout",
+           nortest::lillie.test(x)$p.value)  
+      names(ksout) <- "p_Normal_Lilliefors"
+    } else{
+      suppressWarnings(
+        assign("ksout",
+               ks.test(x, "pnorm", mean(x, na.rm = TRUE), 
+                       sd(x, na.rm = TRUE),
+                       exact = FALSE
+               )$p.value))
+      names(ksout) <- "p_Normal_KS"
+    }
+    
   }else{
     ksout <- NA
   }
@@ -619,14 +630,14 @@ compare2qualvars <- function(data, dep_vars, indep_var,
           data |> 
           select(all_of(c(indep_var,var_i))) |> 
           mutate(testvar=forcats::fct_collapse(!!sym(var_i),
-                                      check=subgroups[sg_i],
-                                      other_level = 'other')) |> 
+                                               check=subgroups[sg_i],
+                                               other_level = 'other')) |> 
           select(all_of(indep_var),'testvar') |> table()
         if(ncol(testdata)>1) {
           p_sg <- fisher.test(testdata,
-                            simulate.p.value = TRUE,
-                            B = 10^5)$p.value |> 
-          formatP(mark = mark, pretext = pretext)
+                              simulate.p.value = TRUE,
+                              B = 10^5)$p.value |> 
+            formatP(mark = mark, pretext = pretext)
         } else{
           p_sg <- ''
         }
@@ -634,7 +645,7 @@ compare2qualvars <- function(data, dep_vars, indep_var,
           freqBYgroup[[var_i]]$p <- 
             paste(na.omit(freqBYgroup[[var_i]]$p),p_sg) |> 
             str_squish()} else {
-        freqBYgroup[[var_i]]$p[sg_i] <- p_sg
+              freqBYgroup[[var_i]]$p[sg_i] <- p_sg
             }
       }
     }
@@ -650,19 +661,19 @@ compare2qualvars <- function(data, dep_vars, indep_var,
   for (var_i in seq_along(dep_vars)) {
     if (!singleline) {
       out_tmp <- add_row(out[0,],
-                     Variable = c(
-                       dep_vars[var_i],
-                       glue::glue(
-                         "{indentor}{levels[[var_i]][[1]]}"
-                       )
-                     ),
-                     desc_all = c(spacer, freq[[var_i]][[1]]),
-                     g1 = c(spacer, freqBYgroup[[var_i]][[1]]),
-                     g2 = c(spacer, freqBYgroup[[var_i]][[2]]),
-                     p = c(
-                       p[[var_i]][[1]],
-                       rep(spacer, nrow(freqBYgroup[[var_i]]))
-                     )
+                         Variable = c(
+                           dep_vars[var_i],
+                           glue::glue(
+                             "{indentor}{levels[[var_i]][[1]]}"
+                           )
+                         ),
+                         desc_all = c(spacer, freq[[var_i]][[1]]),
+                         g1 = c(spacer, freqBYgroup[[var_i]][[1]]),
+                         g2 = c(spacer, freqBYgroup[[var_i]][[2]]),
+                         p = c(
+                           p[[var_i]][[1]],
+                           rep(spacer, nrow(freqBYgroup[[var_i]]))
+                         )
       )
       if(p_subgroups){
         out_tmp$pSubgroup <- c(spacer,freqBYgroup[[var_i]]$p)
@@ -670,16 +681,16 @@ compare2qualvars <- function(data, dep_vars, indep_var,
       out <- rbind(out,out_tmp)
     } else {
       out_tmp <- add_row(out[0,],
-                     Variable = paste(
-                       dep_vars[var_i],
-                       # rep(spacer,
-                       #     nrow(freqBYgroup[[var_i]])-1)),
-                       levels[[var_i]][[1]]
-                     ),
-                     desc_all = freq[[var_i]][[1]],
-                     g1 = freqBYgroup[[var_i]][[1]],
-                     g2 = freqBYgroup[[var_i]][[2]],
-                     p = p[[var_i]][[1]]
+                         Variable = paste(
+                           dep_vars[var_i],
+                           # rep(spacer,
+                           #     nrow(freqBYgroup[[var_i]])-1)),
+                           levels[[var_i]][[1]]
+                         ),
+                         desc_all = freq[[var_i]][[1]],
+                         g1 = freqBYgroup[[var_i]][[1]],
+                         g2 = freqBYgroup[[var_i]][[2]],
+                         p = p[[var_i]][[1]]
       )
       if(p_subgroups){
         out_tmp$pSubgroup <- freqBYgroup[[var_i]]$p
@@ -859,13 +870,13 @@ compare_n_qualvars <- function(data, dep_vars, indep_var,
 #'
 #' \code{pairwise_wilcox_test} calculates pairwise comparisons on ordinal data
 #' between all group levels with corrections for multiple testing based on
-#' \link{wilcox_test} from package 'coin'.
+#' [coin::wilcox_test] from package 'coin'.
 #'
 #' @param dep_var dependent variable, containing the data.
 #' @param indep_var independent variable, should be factor.
 #' @param strat_var optional factor for stratification.
 #' @param adjmethod method for adjusting p values (see [p.adjust])
-#' @param distr Computation of p-values, see \link{wilcox_test}.
+#' @param distr Computation of p-values, see [coin::wilcox_test].
 #' @param plevel threshold for significance.
 #' @param symbols predefined as b,c, d...;  provides footnotes to mark group
 #' differences, e.g. b means different from group 2.
@@ -1012,9 +1023,9 @@ pairwise_t_test <- function(dep_var, indep_var, adjmethod = "fdr", plevel = .05,
 #' # Usually,only the result table is relevant:
 #' compare_n_numvars(
 #'   .data = mtcars, dep_vars = c("wt", "mpg", "hp"),
-#'   indep_var = "drat",
+#'   indep_var = "cyl",
 #'   gaussian = TRUE
-#' )$results
+#'  )$results
 #' # For a report, result columns may be filtered as needed:
 #' compare_n_numvars(
 #'   .data = mtcars, dep_vars = c("wt", "mpg", "hp"),
@@ -1142,7 +1153,7 @@ compare_n_numvars <- function(.data = rawdata,
       collapse = ";")) |>
         pivot_longer(everything(),names_to = 'Variable', 
                      values_to = 'p between groups')) |> 
-        # gather(key = "Variable", value = "p between groups")) |>
+    # gather(key = "Variable", value = "p between groups")) |>
     full_join(purrr::reduce(t$p_wcox_t_out, rbind) |>
                 matrix(nrow = length(dep_vars), byrow = FALSE) |>
                 as_tibble(.name_repair = "unique") |>
@@ -1155,13 +1166,13 @@ compare_n_numvars <- function(.data = rawdata,
     )) |>
       pivot_longer(everything(),names_to = 'Variable', 
                    values_to = 'p vs.ref'))  
-      # gather(key = "Variable", value = "p vs.ref"))
+  # gather(key = "Variable", value = "p vs.ref"))
   results <- cbind(
     results,
     purrr::map2_df(
       .x = dplyr::select(results, starts_with(indep_var)),
       .y = dplyr::select(results, starts_with("sign")),
-      .f = paste
+      .f = ~paste(.x, .y, sep = " ") |> str_squish()
     ) |>
       rename_all(paste, "fn")
   ) |>
